@@ -1,7 +1,7 @@
 import os
 import sys
 import stat
-import backstage
+from backstage.act.act import Act
 import subprocess
 
 class Venue():
@@ -47,35 +47,6 @@ class Venue():
         except:
             return False
 
-    def getallsites(self):
-        """ create a dictionary of all sites, from the database """
-        self.sites = {}
-        self.connect()
-        cur = self.conn.cursor()
-        q = 'select name,id,domain,alldomains,site_db,gunicorn_port from django_site where id <> 1'
-        cur.execute(q)
-        results = cur.fetchall()
-        for r in results:
-            self.sites[r[0]] = {
-                'id': r[1],
-                'domain': str(r[2]),
-                'alldomains': str(r[3]),
-                'site_db': str(r[4]),
-                'gunicorn_port': r[5]
-            }
-
-    def buildallsites(self):
-        """ for each site, create and populate (if necessary) """
-        try:
-            self.sites
-        except:
-            self.getallsites()
-        skel = os.path.join(self.settings.VENUE_ROOT, 'skel/site')
-        for s in self.sites:
-            site = backstage.Site(s)
-            print 'Site:  %s' % (site.sitename)
-            site.populate(replace=False)
-
     def copyskelfile(self, f=None, replace=False):
         """ replace a skel file into all sites """
         if f is None:
@@ -120,10 +91,25 @@ class Venue():
         os.chdir(cwd)
         return
 
+    def get_acts(self):
+        """get this Venue's Acts and find out about them"""
+        self.acts = []
+        acts_root = os.path.abspath(os.path.join(self.VENUE_ROOT,'acts'))
+        acts_list = os.listdir(acts_root)
+        for a in acts_list:
+            try:
+                act=Act(self,a)
+                self.acts.append(act)
+            except:
+                pass
+
+
     def __unicode__(self):
         s = 'Backstage Venue instance %s at %s' % (self.VENUE_NAME, self.VENUE_ROOT)
         return s
 
+
+
 def copy_venue_skel(venue_path):
     """Populate a (usually) new backstage venue with the contents of backstage/skel"""
     skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel/venue')
